@@ -1,23 +1,22 @@
-# /***************************************************************************
-# *            billiard.py
-# *
-# *  Mon Jul 12 20:21:14 2004
-# *  Copyright  2004  Matias Grana,   matiasg@dm.uba.ar
-# *              and  Stas Z,         stas.zytkiewicz@gmail.com
-# ****************************************************************************/
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
+# -*- coding: utf-8 -*-
+
+# Copyright (c) 2006 Stas Zykiewicz <stas.zytkiewicz@gmail.com>
+# Copyright  2004  Matias Grana,   matiasg@dm.uba.ar
+#           billiard.py
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of version 2 of the GNU General Public License
+# as published by the Free Software Foundation.  A copy of this license should
+# be included in the file GPL-2.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Library General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program. If not, write to the Free Software Foundation,
-# 675 Mass Ave, Cambridge, MA 02139, USA.
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+
 
 # Mandatory for a childsplay game.
 RCFILE = 0
@@ -25,8 +24,7 @@ RCFILE = 0
 import os,sys,operator,random,string,locale
 import pygame
 from pygame.constants import *
-from utils import load_image,load_sound,MyError,get_files, load_music,font2surf,\
-    ChildsplayGoodies
+from utils import load_image,load_sound,MyError,get_files, load_music,font2surf
 from SpriteUtils import CPSprite,CPGroup,CPinit
 from math import sqrt,acos
 
@@ -209,10 +207,11 @@ class moving_sign(CPSprite):
 
 class Game(Img):
     """  billiard.py , a billiards game. """
-    def __init__(self, screen, backgr, backcol, basepath, libdir):
+    def __init__(self, screen, backgr, backcol, basepath, libdir, cpg):
         self.screen = screen
         self.backgr = backgr
         self.basedir = libdir
+        self.cpg = cpg
         self.stop = 0
         self.score = 0
         self.level = 1 #No need, see self.gamelevels
@@ -368,7 +367,7 @@ class Game(Img):
             pygame.time.wait(1000)
             s = int(self.pointstoadd / self.throws)
             ## Consider this a placeholder, it doesn't work as it should
-            ChildsplayGoodies.scorething(s)# Update the score display
+            self.cpg.scorething(s)# Update the score display
             self.score += s
             if self.score > self.maxscores[self.level-1]:# see, Game -> gameitems,gamelevels
                 self.stop = -1#signal to childsplay that this level is ended. See return val of def loop
