@@ -1,32 +1,29 @@
 # -*- coding: utf-8 -*-
-#~ /***************************************************************************
- #~ *            packid.py
- #~ *
- #~ *  Fri Oct 22 09:10:15 2004
- #~ *  Copyright  2004-2006  Stas
- #~ *  stas.zytkiewicz@gmail.com
- #~ ****************************************************************************/
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
+
+# Copyright (c) 2006 Stas Zykiewicz <stas.zytkiewicz@gmail.com>
+#
+#           packid.py
+# This program is free software; you can redistribute it and/or
+# modify it under the terms of version 2 of the GNU General Public License
+# as published by the Free Software Foundation.  A copy of this license should
+# be included in the file GPL-2.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Library General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program. If not, write to the Free Software Foundation,
-# 675 Mass Ave, Cambridge, MA 02139, USA.
-#
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+
 RCFILE = 0
 
 import os,random,operator,string,locale,sys
 import pygame
 from pygame.constants import *
 from utils import load_image,load_sound,load_music,MyError,font2surf,MazeGen,\
-                trace_error,get_files,ChildsplayGoodies,read_unicode_file
+                trace_error,get_files,read_unicode_file
 from CPConstants import DATADIR
 
 #0= wall 1=go
@@ -260,12 +257,12 @@ class Letters(Memory):
 
 class Word:
     """  Highlight the letter in the word"""
-    def __init__(self,word,ttf):
+    def __init__(self,word,ttf,cpg):
         self.chars = word
         self.ttf = ttf
         self.index = -1
         self.fsize = 18
-        if ChildsplayGoodies.locale_rtl:
+        if cpg.locale_rtl:
             self.fsize = 24
         self.fcol = (255,255,51)
         self.hfcol = (255,0,0)
@@ -310,7 +307,7 @@ class Word:
         return self.surf        
 
 class SidePanel:
-    def __init__(self,levels,ttf):
+    def __init__(self,levels,ttf,cpg):
         self.ttf = ttf
         self.surf = pygame.Surface((130,400)).convert()
         pygame.draw.rect(self.surf,(42,191,44),self.surf.get_rect(),6)
@@ -320,7 +317,7 @@ class SidePanel:
         self.x = 30
         self.y = 6
         self.fsize = 12
-        if ChildsplayGoodies.locale_rtl:
+        if cpg.locale_rtl:
             self.fsize = 16
         self.fcol = (255,255,51)
         i = 0
@@ -395,7 +392,7 @@ class Game(Img,Snd):
     """  packid.py - part of childsplay.py, a suite of educational games for
   young children."""
 
-    def __init__(self,screen,backgr,rcdic,basepath,libdir):
+    def __init__(self,screen,backgr,rcdic,basepath,libdir,cpg):
         Img.screen = screen
         Img.libdir = libdir
         self.screen = screen
@@ -405,6 +402,8 @@ class Game(Img,Snd):
         self.rcdic = rcdic
         self.basedir  = basepath
         self.libdir = libdir
+        self.cpg = cpg
+        
         self.ttf = os.path.join(DATADIR,'VeraSeBd.ttf')
         self.stop = 0
         self.stopflag = None# used to stop the loop when not level 4
@@ -437,12 +436,12 @@ class Game(Img,Snd):
         Img.pac_smile = load_image(os.path.join(self.libdir,'PackidData','pac_smile.png'),0)
         Img.pac_sad = load_image(os.path.join(self.libdir,'PackidData','pac_sad.png'),0)
         
-        self.sidepan = SidePanel(self.gamelevels,self.ttf)
+        self.sidepan = SidePanel(self.gamelevels,self.ttf,self.cpg)
         
         # test if we have a words list for the locale
         try:
             #loc = locale.setlocale(locale.LC_ALL,'')
-            wordsloc = ChildsplayGoodies.language
+            wordsloc = self.cpg.language
             wordlist = 'words-'+wordsloc
             if not os.path.exists(os.path.join(self.libdir,'PackidData',wordlist)):
                 raise IndexError
@@ -450,7 +449,7 @@ class Game(Img,Snd):
             print >> sys.stderr,info,"\n Can't find words for locale",wordsloc,"\n Using english for the words and sounds."
             wordlist = 'words-en'
             wordsloc = 'en'
-        if ChildsplayGoodies.locale_rtl:
+        if self.cpg.locale_rtl:
             items = read_unicode_file(os.path.join(self.libdir,'PackidData',wordlist))
         else:
             try:
@@ -464,7 +463,7 @@ class Game(Img,Snd):
                 MyError.line = 'IOError in Game.start, words file'
                 raise MyError
 
-        if ChildsplayGoodies.locale_rtl:
+        if self.cpg.locale_rtl:
             self.words = filter(None,map(operator.getslice,items,\
                                         (0,)*len(items),(-1,)*len(items)))
         else:
@@ -538,7 +537,7 @@ class Game(Img,Snd):
         # end of horrible hack 
         ### TODO fix RTL issues here
         if level != 3:
-            if ChildsplayGoodies.locale_rtl:
+            if self.cpg.locale_rtl:
                 surf,spam = font2surf(line1,24,(183,255,50),self.ttf,1)
                 pygame.display.update(self.screen.blit(surf,(780-spam[0],0)))
                 surf,self.surfword_offset = font2surf(line2,24,(183,255,50),self.ttf,1)
@@ -566,7 +565,7 @@ class Game(Img,Snd):
             self.sidepan.set_word(word)
             self._update_sidepanel()
             PLAYWALK = 1
-            self.surfword = Word(word,self.ttf)
+            self.surfword = Word(word,self.ttf,self.cpg)
             self._update_surfword()
         x = 174
         y = 84
@@ -579,7 +578,7 @@ class Game(Img,Snd):
         
     def _update_surfword(self):
         surf, letter_to_speak = self.surfword.update()
-        if ChildsplayGoodies.locale_rtl:
+        if self.cpg.locale_rtl:
             # The Hebrew chars are rendered with a lot of empty space
             # So we cut of the top and bottom to get it to blit in a mal space
             cutoff_rect = surf.get_rect().inflate(0,-10)
